Module ser_stack

Module ser_stack 

Structs

ByteSerializerStack
A byte buffer allocated on stack backed by [u8; CAP], can be reused and recycled by calling Self::clear(). Example: Creates a buffer with 128 bytes capacity and serializes data into it.

Traits

ByteSerializeStack
Trait type accepted by ByteSerializerStack for serialization. Example: Define structure and manually implement ByteSerializeStack trait then use it to serialize.

Functions

to_bytes_stack
Analogous to to_serializer_stack::<CAP>(), but returns just the array of bytes [u8; CAP]. Note that this is not a &[u8] slice, but an array of bytes with length CAP even if the actual length of the serialized data is less.
to_serializer_stack
Analogous to to_bytes_stack::<CAP>(), but returns an instance of ByteSerializerStack<CAP>.