Module byteserde::size

source ·

Traits

  • Trait type used in advanced cases when serializing and deserializing an optional block of a byte stream whose type is represented by a struct whose size is NOT deterministict at compile time.
  • Trait type used in advanced cases when serializing and deserializing an optional block of a byte stream whose type is represented by a struct whose size is deterministict at compile time.