pub fn from_slice<T>(bytes: &[u8]) -> Result<T>where
T: ByteDeserializeSlice<T>,Expand description
This is a short cut method that creates a new instance of ByteDeserializerSlice and then uses that to convert them into a T type struct.
pub fn from_slice<T>(bytes: &[u8]) -> Result<T>where
T: ByteDeserializeSlice<T>,This is a short cut method that creates a new instance of ByteDeserializerSlice and then uses that to convert them into a T type struct.