Traits
- Trait type used in advanced cases when serializing and deserializing an optional block of a byte stream whose type is represented by a
structwhose size isNOTdeterministict at compile time. - Trait type used in advanced cases when serializing and deserializing an optional block of a byte stream whose type is represented by a
structwhose size is deterministict at compile time.